@@ -1,6 +1,6 @@
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,44 +24,9 @@
 
 #include "about.h"
 #include "globalopts.h"
+#include "resources.h"
 #include "version.h"
 
-#define LOGO_SIZE 64
-
-static GdkPixbuf *about_load_logo(void)
-{
-    static GdkPixbuf *result = NULL;
-    static gboolean tried = FALSE;
-
-    if (!tried)
-    {
-        GError *error = NULL;
-        char *filename;
-
-        if (global_options_appdir)
-        {
-            filename = g_build_filename(global_options_appdir,
-                    ".DirIcon", NULL);
-        }
-        else
-        {
-            filename = g_build_filename(ICON_DIR, "roxterm.svg", NULL);
-        }
-        
-        result = gdk_pixbuf_new_from_file_at_size(filename,
-                LOGO_SIZE, LOGO_SIZE, &error);
-        if (error)
-        {
-            g_warning(_("Unable to load logo for about dialog: %s"),
-                    error->message);
-            g_error_free(error);
-        }
-        tried = TRUE;
-        g_free(filename);
-    }
-    return result;
-}
-
 static GtkWidget *about_dialog_create(void)
 {
     GtkWidget *about = gtk_about_dialog_new();
@@ -69,40 +34,28 @@ static GtkWidget *about_dialog_create(void)
     char const *authors[] = { _("Tony Houghton <h@realh.co.uk>"),
         _("Thanks to the developers of VTE"),
         NULL };
-    GdkPixbuf *logo = about_load_logo();
 
     gtk_about_dialog_set_program_name(ad, "ROXTerm");
     gtk_about_dialog_set_version(ad, VERSION);
-    gtk_about_dialog_set_copyright(ad, _("(c) 2005-2011 Tony Houghton"));
-    gtk_about_dialog_set_website(ad, "http://roxterm.sourceforge.net");
+    gtk_about_dialog_set_copyright(ad, _("(c) 2005-2018 Tony Houghton"));
+    gtk_about_dialog_set_website(ad, "https://realh.github.io/roxterm");
     gtk_about_dialog_set_authors(ad, authors);
-    if (logo)
-        gtk_about_dialog_set_logo(ad, logo);
+    resources_access_icon();
+    gtk_about_dialog_set_logo_icon_name(ad, "roxterm");
     return about;
 }
 
 void about_dialog_show(GtkWindow *parent,
-#if USE_ACTIVATE_LINK
         gboolean (*uri_handler)(GtkAboutDialog *, char *, gpointer),
-#else
-        GtkAboutDialogActivateLinkFunc www_hook,
-        GtkAboutDialogActivateLinkFunc email_hook,
-#endif
         gpointer hook_data
 )
 {
     GtkWidget *ad;
 
-#if !USE_ACTIVATE_LINK
-    gtk_about_dialog_set_url_hook(www_hook, hook_data, NULL);
-    gtk_about_dialog_set_email_hook(email_hook, hook_data, NULL);
-#endif
     ad = about_dialog_create();
     if (parent)
         gtk_window_set_transient_for(GTK_WINDOW(ad), parent);
-#if USE_ACTIVATE_LINK
     g_signal_connect(ad, "activate-link", G_CALLBACK(uri_handler), hook_data);
-#endif
     gtk_dialog_run(GTK_DIALOG(ad));
     gtk_widget_destroy(ad);
 }
