@@ -1,6 +1,6 @@
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,14 +23,16 @@
 #include "configlet.h"
 #include "dlg.h"
 #include "dynopts.h"
-#include "encodings.h"
 #include "getname.h"
 #include "optsdbus.h"
 #include "optsfile.h"
 #include "profilegui.h"
+#include "resources.h"
+#include "shortcuts.h"
 
 #include <ctype.h>
 #include <stdarg.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <unistd.h>
@@ -42,28 +44,23 @@ extern gboolean g_file_set_contents(const gchar * filename,
 static int profile_lock = 0;
 static int colours_lock = 0;
 static int shortcuts_lock = 0;
-static int encodings_lock = 0;
 
-typedef struct ConfigletData ConfigletData;
-
-typedef struct {
+struct _ConfigletList {
     const char *family;
     GtkTreeView *tvwidget;
     GtkListStore *list;
     gpointer foreach_data;
-    Encodings *encodings;
     ConfigletData *cg;
-} ConfigletList;
+};
 
-struct ConfigletData {
+struct _ConfigletData {
+    CappletData capp;
     gboolean ignore_destroy;
-    GladeXML *glade;
     GtkWidget *widget;
-    Options *options;
+    GtkSizeGroup *size_group;
     ConfigletList profile;
     ConfigletList colours;
     ConfigletList shortcuts;
-    ConfigletList encodings;
 };
 
 enum {
@@ -75,8 +72,6 @@ enum {
 
 static gboolean ignore_changes = FALSE;
 
-static GladeXML *configlet_glade;
-
 static ConfigletData *configlet_data;
 
 static void set_sensitive_for_list(ConfigletList *cl);
@@ -107,10 +102,6 @@ static const char *full_name_from_family(const char *family)
     {
         return _("Keyboard Shortcuts Scheme");
     }
-    else if (!strcmp(family, "encodings"))
-    {
-        return _("Character Encodings");
-    }
     else
     {
         g_critical(_("Full name for family '%s' not known"), family);
@@ -122,7 +113,9 @@ static void configlet_set_sensitive_button(const char *wbasename,
         const char *butname, gboolean sensitive)
 {
     char *button_name = g_strdup_printf("%s_%s", wbasename, butname);
-    GtkWidget *widget = glade_xml_get_widget(configlet_glade, button_name);
+    GtkWidget *widget =
+            GTK_WIDGET(gtk_builder_get_object(configlet_data->capp.builder,
+                    button_name));
 
     g_free(button_name);
     g_return_if_fail(widget != NULL);
@@ -133,7 +126,7 @@ static void configlet_set_sensitive(const char *wbasename, gboolean sensitive)
 {
     int lock;
 
-    if (!configlet_glade)
+    if (!configlet_data)
         return;
     if (!strcmp(wbasename, "profile"))
     {
@@ -147,10 +140,6 @@ static void configlet_set_sensitive(const char *wbasename, gboolean sensitive)
     {
         lock = shortcuts_lock;
     }
-    else if (!strcmp(wbasename, "encodings"))
-    {
-        lock = encodings_lock;
-    }
     else
     {
         g_critical(_("Bad options family basename '%s'"), wbasename);
@@ -162,23 +151,16 @@ static void configlet_set_sensitive(const char *wbasename, gboolean sensitive)
 
 static gboolean is_in_user_dir(const char *family, const char *profile_name)
 {
-    if (!strcmp(family, "encodings"))
-    {
-        return strcmp(profile_name, "Default") != 0;
-    }
-    else
-    {
-        char *pathname = options_file_build_filename(family, profile_name,
-                NULL);
-        char *savename = options_file_filename_for_saving(family,
-                profile_name, NULL);
-        gboolean result = (pathname != NULL) && !strcmp(savename, pathname);
+    char *pathname = options_file_build_filename(family, profile_name,
+            NULL);
+    char *savename = options_file_filename_for_saving(family,
+            profile_name, NULL);
+    gboolean result = (pathname != NULL) && !strcmp(savename, pathname);
 
-        g_free(savename);
-        g_free(pathname);
+    g_free(savename);
+    g_free(pathname);
 
-        return result;
-    }
+    return result;
 }
 
 static void shade_actions_for_name(ConfigletList *cl, const char *name)
@@ -197,11 +179,10 @@ static void configlet_delete(ConfigletData *cg)
         gtk_widget_destroy(cg->widget);
         cg->widget = NULL;
     }
-    if (cg->glade)
+    if (cg->capp.builder)
     {
-        UNREF_LOG(g_object_unref(cg->glade));
-        cg->glade = NULL;
-        configlet_glade = NULL;
+        UNREF_LOG(g_object_unref(cg->capp.builder));
+        cg->capp.builder = NULL;
     }
     g_free(cg);
     configlet_data = NULL;
@@ -216,8 +197,6 @@ static const char *family_name_to_opt_key(const char *family)
         return "colour_scheme";
     else if (!strcmp(family, "Shortcuts"))
         return "shortcut_scheme";
-    else if (!strcmp(family, "encodings"))
-        return "encoding";
     return NULL;
 }
 
@@ -226,7 +205,7 @@ static char *configlet_get_configured_name(ConfigletList *cl)
     const char *optkey = family_name_to_opt_key(cl->family);
 
     g_return_val_if_fail(optkey, NULL);
-    return options_lookup_string_with_default(cl->cg->options, optkey,
+    return options_lookup_string_with_default(cl->cg->capp.options, optkey,
             strcmp(cl->family, "Colours") ? "Default" : "GTK");
 }
 
@@ -236,15 +215,8 @@ static void configlet_list_build(ConfigletList *cl)
     char const **pitem;
     char *selected_name = configlet_get_configured_name(cl);
 
-    if (cl->encodings)
-    {
-        item_list = encodings_list(cl->encodings);
-    }
-    else
-    {
-        item_list = (char const **) dynamic_options_list_sorted(
-                dynamic_options_get(cl->family));
-    }
+    item_list = (char const **) dynamic_options_list_sorted(
+            dynamic_options_get(cl->family));
 
     if (cl->list)
     {
@@ -266,10 +238,7 @@ static void configlet_list_build(ConfigletList *cl)
                 cfColumn_Name, *pitem,
                 -1);
     }
-    if (cl->encodings)
-        g_free(item_list);
-    else
-        g_strfreev((char **) item_list);
+    g_strfreev((char **) item_list);
     g_free(selected_name);
 }
 
@@ -279,6 +248,7 @@ static gboolean foreach_find_name(GtkTreeModel *model, GtkTreePath *path,
 {
     char *name = NULL;
     ConfigletList *cl = data;
+    (void) path;
 
     gtk_tree_model_get(model, iter, cfColumn_Name, &name, -1);
     if (name && cl->foreach_data && !strcmp(name, cl->foreach_data))
@@ -319,6 +289,7 @@ gboolean update_radios(GtkTreeModel *model,
         GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
     char *name = NULL;
+    (void) path;
 
     gtk_tree_model_get(model, iter, cfColumn_Name, &name, -1);
     gtk_list_store_set(GTK_LIST_STORE(model), iter, cfColumn_Radio,
@@ -334,6 +305,7 @@ static void configlet_cell_toggled(GtkCellRendererToggle *cell,
     GtkTreeIter iter;
     char *name;
     gboolean active;
+    (void) cell;
 
     g_return_if_fail(
             gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(cl->list),
@@ -344,9 +316,9 @@ static void configlet_cell_toggled(GtkCellRendererToggle *cell,
     if (!active)
     {
         gtk_tree_model_foreach(GTK_TREE_MODEL(cl->list), update_radios, name);
-        options_set_string(cl->cg->options,
+        options_set_string(cl->cg->capp.options,
                 family_name_to_opt_key(cl->family), name);
-        capplet_save_file(cl->cg->options);
+        capplet_save_file(cl->cg->capp.options);
     }
     g_free(name);
 }
@@ -400,8 +372,9 @@ static void configlet_list_init(ConfigletList *cl, GtkWidget *widget,
 /********************************************************************/
 /* Generic handlers */
 
-static void on_Configlet_destroy(GtkWidget * widget, ConfigletData * cg)
+void on_Configlet_destroy(GtkWidget * widget, ConfigletData * cg)
 {
+    (void) widget;
     if (cg->ignore_destroy)
     {
         return;
@@ -413,14 +386,16 @@ static void on_Configlet_destroy(GtkWidget * widget, ConfigletData * cg)
     }
 }
 
-static void on_Configlet_response(GtkWidget * widget, int response,
-        ConfigletData * cg)
+void on_Configlet_response(GtkWidget * widget, int response, ConfigletData * cg)
 {
+    (void) response;
+    (void) widget;
     configlet_delete(cg);
 }
 
-static void on_Configlet_close(GtkWidget * widget, ConfigletData * cg)
+void on_Configlet_close(GtkWidget * widget, ConfigletData * cg)
 {
+    (void) widget;
     configlet_delete(cg);
 }
 
@@ -488,14 +463,14 @@ static gboolean find_list_insert_point(ConfigletList *cl, const char *new_name,
         GtkTreeIter *iter)
 {
     GtkTreeModel *tm = GTK_TREE_MODEL(cl->list);
-    
+
     if (gtk_tree_model_get_iter_first(tm, iter))
     {
         do
         {
             char *n;
             int cmp;
-            
+
             gtk_tree_model_get(tm, iter, cfColumn_Name, &n, -1);
             cmp = dynamic_options_strcmp(new_name, n);
             g_free(n);
@@ -540,25 +515,22 @@ static void add_name_to_list(ConfigletList *cl, const char *new_name)
 static gboolean remove_name_from_list(ConfigletList *cl, const char *old_name)
 {
     gboolean remove = TRUE;
-
-    if (!cl->encodings)
-    {
         char **name_list =
             dynamic_options_list(dynamic_options_get(cl->family));
-        char **pname;
+    char **pname;
 
-        for (pname = name_list; *pname; ++pname)
+    for (pname = name_list; *pname; ++pname)
+    {
+        if (!strcmp(old_name, *pname))
         {
-            if (!strcmp(old_name, *pname))
-            {
-                remove = FALSE;
-                dlg_message(GTK_WINDOW(cl->cg->widget),
-                        _("'%s' will now refer to a %s provided by the system"),
-                        old_name, full_name_from_family(cl->family));
-            }
+            remove = FALSE;
+            dlg_message(GTK_WINDOW(cl->cg->widget),
+                    _("'%s' will now refer to a %s provided by the system"),
+                    old_name, full_name_from_family(cl->family));
         }
-        g_strfreev(name_list);
     }
+    g_strfreev(name_list);
+
     if (remove)
     {
         GtkTreeIter iter;
@@ -571,92 +543,36 @@ static gboolean remove_name_from_list(ConfigletList *cl, const char *old_name)
     return remove;
 }
 
-/* This is Add for Encodings */
 static void configlet_copy(ConfigletList *cl,
         const char *old_leaf, const char *new_leaf)
 {
-    GError *error = NULL;
     gboolean success = FALSE;
+    char *old_path = options_file_build_filename(cl->family, old_leaf,
+            NULL);
 
-    if (cl->encodings)
-    {
-        encodings_add(cl->encodings, new_leaf);
-        encodings_save(cl->encodings);
-        success = TRUE;
-    }
-    else
-    {
-        char *old_path = options_file_build_filename(cl->family, old_leaf,
-                NULL);
-        char *new_path = options_file_filename_for_saving(cl->family,
-            new_leaf, NULL);
-        char *dir = options_file_filename_for_saving(cl->family, NULL);
-        char *buffer = NULL;
-        gsize size;
-
-        if (!g_file_test(dir, G_FILE_TEST_IS_DIR))
-        {
-            if (g_mkdir_with_parents(dir, 0755) == -1)
-            {
-                dlg_warning(GTK_WINDOW(cl->cg->widget),
-                        _("Unable to create directory '%s'"), dir);
-                return;
-            }
-        }
-        if (g_file_test(old_path, G_FILE_TEST_IS_REGULAR))
-        {
-            if (g_file_get_contents(old_path, &buffer, &size, &error))
-                success = g_file_set_contents(new_path, buffer, size, &error);
-        }
-        else
-        {
-            success = g_file_set_contents(new_path, "", -1, &error);
-        }
-        g_free(buffer);
-        g_free(new_path);
-        g_free(old_path);
-    }
+    success = options_file_copy_to_user_dir(GTK_WINDOW(cl->cg->widget),
+            old_path, cl->family, new_leaf);
+    g_free(old_path);
     if (success)
     {
         add_name_to_list(cl, new_leaf);
         optsdbus_send_stuff_changed_signal(OPTSDBUS_ADDED, cl->family,
                 new_leaf, NULL);
     }
-    else
-    {
-        dlg_warning(GTK_WINDOW(cl->cg->widget),
-                _("Unable to copy profile/scheme: %s"),
-                error && error->message ? error->message : _("unknown reason"));
-    }
-    if (error)
-        g_error_free(error);
 }
 
-/* This is Edit for Encodings */
 static void configlet_rename(ConfigletList *cl,
         const char *old_leaf, const char *new_leaf)
 {
     gboolean success = FALSE;
+    char *old_path = options_file_build_filename(cl->family, old_leaf,
+            NULL);
+    char *new_path = options_file_filename_for_saving(cl->family,
+        new_leaf, NULL);
 
-    if (cl->encodings)
-    {
-        int n = get_selected_index(cl);
-
-        encodings_change(cl->encodings, n - 1, new_leaf);
-        encodings_save(cl->encodings);
-        success = TRUE;
-    }
-    else
-    {
-        char *old_path = options_file_build_filename(cl->family, old_leaf,
-                NULL);
-        char *new_path = options_file_filename_for_saving(cl->family,
-            new_leaf, NULL);
-
-        success = (g_rename(old_path, new_path) == 0);
-        g_free(new_path);
-        g_free(old_path);
-    }
+    success = (g_rename(old_path, new_path) == 0);
+    g_free(new_path);
+    g_free(old_path);
     if (success)
     {
         GtkTreeModel *model;
@@ -691,26 +607,17 @@ static void configlet_rename(ConfigletList *cl,
 
 static void edit_thing_by_name(ConfigletList *cl, const char *name)
 {
-    GdkScreen *scrn = gtk_widget_get_screen(cl->cg->widget);
-    
     if (!strcmp(cl->family, "Profiles"))
     {
-        profilegui_open(name, scrn);
+        profilegui_open(name);
     }
     else if (!strcmp(cl->family, "Colours"))
     {
-        colourgui_open(name, scrn);
+        colourgui_open(name);
     }
     else if (!strcmp(cl->family, "Shortcuts"))
     {
-        dlg_message(GTK_WINDOW(cl->cg->widget),
-                _("Shortcuts can currently only be edited by hovering "
-                    "over the menu entries and pressing keys"));
-    }
-    else if (cl->encodings)
-    {
-        dlg_message(GTK_WINDOW(cl->cg->widget),
-                _("Encoding names have no properties"));
+        shortcuts_edit(GTK_WINDOW(cl->cg->widget), name);
     }
     else
     {
@@ -745,15 +652,26 @@ static gboolean edit_selected_thing(ConfigletList *cl)
     return TRUE;
 }
 
-static void on_edit_clicked(GtkButton *button, ConfigletList *cl)
+void on_profile_edit_clicked(GtkButton *button, ConfigletData *cg)
 {
-    edit_selected_thing(cl);
+    (void) button;
+    edit_selected_thing(&cg->profile);
 }
 
-static void on_row_activated(GtkTreeView *tvwidget, GtkTreePath *path,
-        GtkTreeViewColumn *column, ConfigletList *cl)
+void on_colours_edit_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    edit_selected_thing(&cg->colours);
+}
+
+void on_row_activated(GtkTreeView *tvwidget, GtkTreePath *path,
+        GtkTreeViewColumn *column, ConfigletData *cg)
 {
     GtkTreeIter iter;
+    ConfigletList *cl = g_object_get_data(G_OBJECT(tvwidget),
+            "ROXTermConfigletList");
+    (void) column;
+    (void) cg;
 
     if (gtk_tree_model_get_iter(GTK_TREE_MODEL(cl->list), &iter, path))
         edit_thing_by_iter(cl, &iter);
@@ -765,6 +683,7 @@ static void on_tree_selection_changed(GtkTreeSelection *selection,
         ConfigletList *cl)
 {
     char *name = get_selected_name(cl);
+    (void) selection;
 
     if (name)
     {
@@ -773,34 +692,22 @@ static void on_tree_selection_changed(GtkTreeSelection *selection,
     }
 }
 
-/* This is Add for Encodings */
-static void on_copy_clicked(GtkButton *button, ConfigletList *cl)
+static void on_copy_clicked(ConfigletList *cl)
 {
     char *old_name = get_selected_name(cl);
     char *title = NULL;
     const char *button_label = NULL;
     const char **existing = NULL;
+    DynamicOptions *dynopts = dynamic_options_get(cl->family);
 
-    if (cl->encodings)
-    {
-        title = g_strdup_printf(_("Add Encoding"));
-        button_label = GTK_STOCK_ADD;
-        existing = encodings_list(cl->encodings);
-    }
-    else
-    {
-        DynamicOptions *dynopts = dynamic_options_get(cl->family);
-
-        title = g_strdup_printf(_("Copy %s"),
-            full_name_from_family(cl->family));
-        button_label = GTK_STOCK_COPY;
-        existing = (char const **) dynamic_options_list(dynopts);
-    }
-    if (old_name || cl->encodings)
+    title = g_strdup_printf(_("Copy %s"),
+        full_name_from_family(cl->family));
+    button_label = _("_Copy");
+    existing = (char const **) dynamic_options_list(dynopts);
+    if (old_name)
     {
         char *new_name = getname_run_dialog(GTK_WINDOW(cl->cg->widget),
-                old_name, existing, title, button_label, NULL,
-                cl->encodings == NULL);
+                old_name, existing, title, button_label, NULL, TRUE);
 
         if (new_name)
         {
@@ -813,14 +720,29 @@ static void on_copy_clicked(GtkButton *button, ConfigletList *cl)
     {
         g_warning(_("No selection to copy"));
     }
-    if (cl->encodings)
-        g_free(existing);
-    else
-        g_strfreev((char **) existing);
+    g_strfreev((char **) existing);
     g_free(title);
 }
 
-static void on_delete_clicked(GtkButton *button, ConfigletList *cl)
+void on_profile_copy_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_copy_clicked(&cg->profile);
+}
+
+void on_colours_copy_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_copy_clicked(&cg->colours);
+}
+
+void on_shortcuts_copy_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_copy_clicked(&cg->shortcuts);
+}
+
+static void on_delete_clicked(ConfigletList *cl)
 {
     char *name;
 
@@ -846,28 +768,16 @@ static void on_delete_clicked(GtkButton *button, ConfigletList *cl)
     else
     {
         gboolean remove = TRUE;
+        char *filename = options_file_build_filename(cl->family,
+                name, NULL);
 
-        if (cl->encodings)
+        if (g_unlink(filename))
         {
-            int n = get_selected_index(cl);
-
-            g_return_if_fail(n > 0);
-            encodings_remove(cl->encodings, n - 1);
-            encodings_save(cl->encodings);
-        }
-        else
-        {
-            char *filename = options_file_build_filename(cl->family,
-                    name, NULL);
-
-            if (g_unlink(filename))
-            {
-                dlg_warning(GTK_WINDOW(cl->cg->widget),
-                        _("Unable to delete '%s'"), filename);
-                remove = FALSE;
-            }
-            g_free(filename);
+            dlg_warning(GTK_WINDOW(cl->cg->widget),
+                    _("Unable to delete '%s'"), filename);
+            remove = FALSE;
         }
+        g_free(filename);
         if (remove)
         {
             if (remove_name_from_list(cl, name))
@@ -880,31 +790,44 @@ static void on_delete_clicked(GtkButton *button, ConfigletList *cl)
     g_free(name);
 }
 
-/* This is Edit for Encodings */
-static void on_rename_clicked(GtkButton *button, ConfigletList *cl)
+void on_profile_delete_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_delete_clicked(&cg->profile);
+}
+
+void on_colours_delete_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_delete_clicked(&cg->colours);
+}
+
+void on_shortcuts_delete_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_delete_clicked(&cg->shortcuts);
+}
+
+void on_shortcuts_edit_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    edit_selected_thing(&cg->shortcuts);
+}
+
+void on_rename_clicked(ConfigletList *cl)
 {
     char *title = NULL;
     char const **existing = NULL;
     char *old_name = get_selected_name(cl);
+    DynamicOptions *dynopts = dynamic_options_get(cl->family);
 
-    if (cl->encodings)
-    {
-        title = g_strdup_printf(_("Edit Encoding"));
-        existing = encodings_list(cl->encodings);
-    }
-    else
-    {
-        DynamicOptions *dynopts = dynamic_options_get(cl->family);
-
-        title = g_strdup_printf(_("Rename %s"),
-            full_name_from_family(cl->family));
-        existing = (char const **) dynamic_options_list(dynopts);
-    }
-    if (old_name || cl->encodings)
+    title = g_strdup_printf(_("Rename %s"),
+        full_name_from_family(cl->family));
+    existing = (char const **) dynamic_options_list(dynopts);
+    if (old_name)
     {
         char *new_name = getname_run_dialog(GTK_WINDOW(cl->cg->widget),
-                old_name, existing, title, GTK_STOCK_APPLY, NULL,
-                cl->encodings == NULL);
+                old_name, existing, title, _("Apply"), NULL, TRUE);
 
         if (new_name)
         {
@@ -917,60 +840,48 @@ static void on_rename_clicked(GtkButton *button, ConfigletList *cl)
     {
         g_warning(_("No selection to copy"));
     }
-    if (cl->encodings)
-        g_free(existing);
-    else
-        g_strfreev((char **) existing);
+    g_strfreev((char **) existing);
     g_free(title);
 }
 
+void on_profile_rename_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_rename_clicked(&cg->profile);
+}
+
+void on_colours_rename_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_rename_clicked(&cg->colours);
+}
+
+void on_shortcuts_rename_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    on_rename_clicked(&cg->shortcuts);
+}
+
 /********************************************************************/
 
-#define CONFIGLET_CONNECT(glade, data, h) \
-    glade_xml_signal_connect_data(glade, #h, (GCallback) h, (data))
-
-#define CG_CONNECT(cg, h) \
-    CONFIGLET_CONNECT((cg)->glade, cg, h)
-
-
-static void connect_generic_handlers(ConfigletData *cg)
+static void configlet_add_button_to_size_group(ConfigletData *cg,
+        const char *family, const char *button)
 {
-    CG_CONNECT(cg, on_Configlet_destroy);
-    CG_CONNECT(cg, on_Configlet_close);
-    CG_CONNECT(cg, on_Configlet_response);
+    char *obj_name = g_strdup_printf("%c%s_%s",
+            tolower(family[0]), family + 1, button);
+    gtk_size_group_add_widget(cg->size_group,
+            GTK_WIDGET(gtk_builder_get_object(cg->capp.builder, obj_name)));
+    g_free(obj_name);
 }
 
-static void connect_a_list_handler(ConfigletList *cl, GladeXML *glade,
-        const char *wbasename, const char *signame_stub, GCallback handler)
+static void configlet_add_family_to_size_group(ConfigletData *cg,
+        const char *family)
 {
-    char *signame;
-
-    signame = g_strdup_printf("on_%s_%s_clicked", wbasename, signame_stub);
-    glade_xml_signal_connect_data(glade, signame, handler, cl);
-    g_free(signame);
-}
-
-static void connect_list_handlers(ConfigletList *cl, GladeXML *glade)
-{
-    char *wbasename = convert_family_name(cl->family);
-
-    if (!cl->encodings && strcmp(cl->family, "Shortcuts"))
-    {
-        connect_a_list_handler(cl, glade, wbasename, "edit",
-                G_CALLBACK(on_edit_clicked));
-        g_signal_connect(cl->tvwidget, "row-activated",
-                G_CALLBACK(on_row_activated), cl);
-    }
-    connect_a_list_handler(cl, glade, wbasename, "delete",
-            G_CALLBACK(on_delete_clicked));
-    connect_a_list_handler(cl, glade, wbasename, "copy",
-            G_CALLBACK(on_copy_clicked));
-    connect_a_list_handler(cl, glade, wbasename, "rename",
-            G_CALLBACK(on_rename_clicked));
-    g_free(wbasename);
-
-    g_signal_connect(gtk_tree_view_get_selection(cl->tvwidget), "changed",
-                  G_CALLBACK(on_tree_selection_changed), cl);
+    const char *f2 = strcmp(family, "Profiles") ? family : "profile";
+    configlet_add_button_to_size_group(cg, f2, "copy");
+    configlet_add_button_to_size_group(cg, f2, "rename");
+    configlet_add_button_to_size_group(cg, f2, "delete");
+    configlet_add_button_to_size_group(cg, f2, "edit");
 }
 
 static void configlet_setup_family(ConfigletData *cg, ConfigletList *cl,
@@ -978,61 +889,90 @@ static void configlet_setup_family(ConfigletData *cg, ConfigletList *cl,
 {
     char *wbasename = convert_family_name(family);
     char *widget_name = g_strdup_printf("%s_treeview", wbasename);
-    GtkWidget *widget = glade_xml_get_widget(cg->glade, widget_name);
+    GtkWidget *widget =
+            GTK_WIDGET(gtk_builder_get_object(cg->capp.builder, widget_name));
     char *cname;
 
     g_free(widget_name);
     g_return_if_fail(widget != NULL);
     cl->cg = cg;
+    g_object_set_data(G_OBJECT(widget), "ROXTermConfigletList", cl);
     configlet_list_init(cl, widget, family);
     shade_actions_for_name(cl, cname = configlet_get_configured_name(cl));
     g_free(cname);
-    connect_list_handlers(cl, cg->glade);
     g_free(wbasename);
+    /* If size_group is NULL it means actions_sizegroup was found in the UI
+     * file and we don't need to do anything.
+     */
+    if (cg->size_group)
+    {
+        configlet_add_family_to_size_group(cg, family);
+    }
 }
 
-gboolean configlet_open(GdkScreen *scrn)
+gboolean configlet_open()
 {
-    
+
     if (configlet_data)
     {
-        if (scrn)
-            gtk_window_set_screen(GTK_WINDOW(configlet_data->widget), scrn);
         gtk_window_present(GTK_WINDOW(configlet_data->widget));
     }
     else
     {
+        static char const *build_objs[] = { "Configlet", NULL };
         ConfigletData *cg = configlet_data = g_new0(ConfigletData, 1);
+        GError *error = NULL;
 
-        cg->glade = glade_xml_new(capplet_get_glade_filename(),
-                "Configlet", NULL);
-        if (cg->glade)
-            cg->widget = glade_xml_get_widget(cg->glade, "Configlet");
+        cg->capp.builder = gtk_builder_new();
+        if (gtk_builder_add_objects_from_resource(cg->capp.builder,
+                ROXTERM_RESOURCE_UI, (char **) build_objs, &error))
+        {
+            cg->widget =
+                    GTK_WIDGET(gtk_builder_get_object(cg->capp.builder,
+                            "Configlet"));
+        }
+        else
+        {
+            g_critical(_("Unable to create 'Configlet' from UI definition: %s"),
+                    error->message);
+            g_error_free(error);
+        }
         if (!cg->widget)
         {
             configlet_delete(cg);
             return FALSE;
         }
-        if (scrn)
-            gtk_window_set_screen(GTK_WINDOW(cg->widget), scrn);
-        configlet_glade = cg->glade;
 
-        cg->options = options_open("Global", "roxterm options");
+        /* GtkBuilder doesn't seem to load size group. Bug? If the size group
+         * does load after all we probably don't need to do anything further,
+         * otherwise we have to create our own and add widgets manually.
+         */
+        GObject *size_group = gtk_builder_get_object(cg->capp.builder,
+                "actions_sizegroup");
+        cg->size_group = size_group ? NULL :
+            gtk_size_group_new(GTK_SIZE_GROUP_BOTH);
 
-        cg->encodings.encodings = encodings_load();
+        cg->capp.options = options_open("Global", "roxterm options");
 
-        connect_generic_handlers(cg);
-        CONFIGLET_CONNECT(cg->glade, cg->options, on_boolean_toggled);
-        CONFIGLET_CONNECT(cg->glade, cg->options, on_radio_toggled);
+        gtk_builder_connect_signals(cg->capp.builder, cg);
 
         configlet_setup_family(cg, &cg->profile, "Profiles");
         configlet_setup_family(cg, &cg->colours, "Colours");
         configlet_setup_family(cg, &cg->shortcuts, "Shortcuts");
-        configlet_setup_family(cg, &cg->encodings, "encodings");
-        
-        capplet_set_radio(cg->glade, cg->options, "warn_close", 2);
-        capplet_set_boolean_toggle(cg->glade, cg->options,
-                "edit_shortcuts", FALSE);
+
+        capplet_set_radio(&cg->capp, "warn_close", 3);
+        capplet_set_boolean_toggle(&cg->capp, "only_warn_running", FALSE);
+        if (g_object_class_find_property(
+                G_OBJECT_GET_CLASS(gtk_settings_get_default()),
+                "gtk-application-prefer-dark-theme"))
+        {
+            capplet_set_boolean_toggle(&cg->capp, "prefer_dark_theme", FALSE);
+        }
+        else
+        {
+            gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(cg->capp.builder,
+                    "prefer_dark_theme")));
+        }
 
         capplet_inc_windows();
         gtk_widget_show(cg->widget);
@@ -1099,22 +1039,4 @@ void configlet_unlock_shortcuts(void)
         set_sensitive_for_list(&configlet_data->shortcuts);
 }
 
-void configlet_lock_encodings(void)
-{
-    ++encodings_lock;
-    if (configlet_data)
-        set_sensitive_for_list(&configlet_data->encodings);
-}
-
-void configlet_unlock_encodings(void)
-{
-    if (--encodings_lock < 0)
-    {
-        g_critical(_("Trying to decrease encodings_lock below 0"));
-        encodings_lock = 0;
-    }
-    if (configlet_data)
-        set_sensitive_for_list(&configlet_data->encodings);
-}
-
 /* vi:set sw=4 ts=4 noet cindent cino= */
