@@ -2,7 +2,7 @@
 #define DEFNS_H
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Always include this first.
  */
 
-#include "rtconfig.h"
+#include "config.h"
 
 #include <gtk/gtk.h>
 
@@ -66,18 +66,10 @@ enum {
 
 #define ROXTERM_LEAF_DIR "roxterm.sourceforge.net"
 
-#ifndef HAVE_GTK_WIDGET_GET_REALIZED
-#define gtk_widget_get_realized GTK_WIDGET_REALIZED
-#endif
-
-#ifndef HAVE_GTK_WIDGET_GET_MAPPED
-#define gtk_widget_get_mapped GTK_WIDGET_MAPPED
-#endif
-
 /* Whether to try to prevent tabs from being too wide to unmaximize correctly.
  * <http://mail.gnome.org/archives/gtk-devel-list/2011-September/msg00214.html
  */
-#define MULTITAB_LABEL_GTK3_SIZE_KLUDGE GTK_CHECK_VERSION(3, 0, 0)
+#define MULTITAB_LABEL_GTK3_SIZE_KLUDGE FALSE
 
 #endif /* DEFNS_H */
 
