@@ -1,8 +1,8 @@
 #ifndef DRAGRCV_H
 #define DRAGRCV_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
