@@ -1,6 +1,6 @@
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -69,16 +69,17 @@ char *getname_run_dialog(GtkWindow *parent, const char *old_name,
 	GtkWidget *dialog;
 	GtkWidget *name_field;
 	char *new_name = NULL;
-	
+    (void) icon;
+
 	dialog = gtk_dialog_new_with_buttons(title, parent,
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			_("_Cancel"), GTK_RESPONSE_CANCEL,
 			button_label, GTK_RESPONSE_OK,
 			NULL);
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 	name_field = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX((GTK_DIALOG(dialog))->vbox), name_field,
-			FALSE, FALSE, 16);
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
+	        name_field, FALSE, FALSE, 16);
 	gtk_entry_set_activates_default(GTK_ENTRY(name_field), TRUE);
 	gtk_widget_show(name_field);
 
@@ -114,7 +115,7 @@ char *getname_run_dialog(GtkWindow *parent, const char *old_name,
 						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 						_("An item with that name already exists"));
-					
+
 				gtk_dialog_run(GTK_DIALOG(error_box));
 				gtk_widget_destroy(error_box);
 				new_name = NULL;
