@@ -1,6 +1,6 @@
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,24 +30,9 @@ static char const *menutree_labels[MENUTREE_NUM_IDS];
 static gboolean filled_labels = FALSE;
 
 static GtkWidget *menutree_append_new_item_with_mnemonic(
-        GtkMenuShell *shell,
-        const char *label, const char *stock, gboolean separate_label)
+        GtkMenuShell *shell, const char *label)
 {
-    GtkWidget *item;
-        
-    if (stock)
-    {
-        item = gtk_image_menu_item_new_from_stock(stock, NULL);
-        if (separate_label)
-        {
-            gtk_menu_item_set_label(GTK_MENU_ITEM(item), label);
-            gtk_menu_item_set_use_underline(GTK_MENU_ITEM(item), TRUE);
-        }
-    }
-    else
-    {
-        item = gtk_menu_item_new_with_mnemonic(label);
-    }
+    GtkWidget *item = gtk_menu_item_new_with_mnemonic(label);
 
     gtk_menu_shell_append(shell, item);
     return item;
@@ -88,9 +73,6 @@ static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
         }
         else
         {
-            gboolean separate_label = FALSE;
-            const char *stock = NULL;
-
             if (!filled_labels &&
                     id < MENUTREE_NUM_IDS && id != MENUTREE_NULL_ID)
             {
@@ -98,85 +80,18 @@ static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
             }
             if (menu_tree->disable_shortcuts)
                 label = strip_underscore(label);
-            switch (id)
-            {
-                case MENUTREE_FILE_NEW_WINDOW:
-                case MENUTREE_FILE_NEW_TAB:
-                    stock = GTK_STOCK_NEW;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_FILE_CLOSE_WINDOW:
-                case MENUTREE_FILE_CLOSE_TAB:
-                case MENUTREE_TABS_CLOSE_TAB:
-                    stock = GTK_STOCK_CLOSE;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_EDIT_COPY:
-                    stock = GTK_STOCK_COPY;
-                    break;
-                case MENUTREE_EDIT_PASTE:
-                    stock = GTK_STOCK_PASTE;
-                    break;
-                case MENUTREE_EDIT_SET_WINDOW_TITLE:
-                case MENUTREE_TABS_NAME_TAB:
-                    stock = GTK_STOCK_EDIT;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_EDIT_RESET:
-                case MENUTREE_EDIT_RESET_AND_CLEAR:
-                    stock = GTK_STOCK_CLEAR;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_EDIT_RESPAWN:
-                    stock = GTK_STOCK_REFRESH;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_VIEW_ZOOM_IN:
-                    stock = GTK_STOCK_ZOOM_IN;
-                    break;
-                case MENUTREE_VIEW_ZOOM_OUT:
-                    stock = GTK_STOCK_ZOOM_OUT;
-                    break;
-                case MENUTREE_VIEW_ZOOM_NORM:
-                    stock = GTK_STOCK_ZOOM_100;
-                    break;
-#ifdef HAVE_VTE_TERMINAL_SEARCH_SET_GREGEX
-                case MENUTREE_SEARCH_FIND:
-                case MENUTREE_SEARCH_FIND_NEXT:
-                case MENUTREE_SEARCH_FIND_PREVIOUS:
-                    stock = GTK_STOCK_FIND;
-                    separate_label = TRUE;
-                    break;
-#endif
-                case MENUTREE_PREFERENCES_EDIT_CURRENT_PROFILE:
-                    stock = GTK_STOCK_PREFERENCES;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_PREFERENCES_EDIT_CURRENT_COLOUR_SCHEME:
-                    stock = GTK_STOCK_SELECT_COLOR;
-                    separate_label = TRUE;
-                    break;
-                case MENUTREE_HELP_SHOW_MANUAL:
-                    stock = GTK_STOCK_HELP;
-                    break;
-                case MENUTREE_HELP_ABOUT:
-                    stock = GTK_STOCK_ABOUT;
-                    break;
-                default:
-                    break;
-            }
             item = NULL;
             switch (id)
             {
                 case MENUTREE_VIEW_SHOW_MENUBAR:
                 case MENUTREE_VIEW_SHOW_TAB_BAR:
                 case MENUTREE_VIEW_FULLSCREEN:
+                case MENUTREE_VIEW_BORDERLESS:
                     item = gtk_check_menu_item_new_with_mnemonic(label);
                     gtk_menu_shell_append(shell, item);
                     break;
                 default:
-                    item = menutree_append_new_item_with_mnemonic(shell,
-                            label, stock, separate_label);
+                    item = menutree_append_new_item_with_mnemonic(shell, label);
                     break;
             }
             if (menu_tree->disable_shortcuts)
@@ -198,17 +113,15 @@ static void menutree_build_shell(MenuTree *menu_tree, GtkMenuShell * shell, ...)
 }
 
 #define URI_MENU_ITEMS \
-        _("_Open URL in browser"), MENUTREE_OPEN_IN_BROWSER, \
-        _("_Send email"), MENUTREE_OPEN_IN_MAILER, \
+        _("_SSH to host"), MENUTREE_SSH_HOST, \
+        _("_Open link"), MENUTREE_OPEN_IN_BROWSER, \
+        _("Send e_mail"), MENUTREE_OPEN_IN_MAILER, \
         _("_Open file/directory in filer"), MENUTREE_OPEN_IN_FILER, \
+        _("_Call"), MENUTREE_VOIP_CALL, \
         _("_Copy address to clipboard"), MENUTREE_COPY_URI, \
         _("_"), MENUTREE_URI_SEPARATOR
-        
-#ifdef HAVE_VTE_TERMINAL_SEARCH_SET_GREGEX
+
 #define MENUTREE_SEARCH_ITEM _("_Search"), MENUTREE_SEARCH,
-#else
-#define MENUTREE_SEARCH_ITEM
-#endif
 #define TOP_LEVEL_MENU_ITEMS \
         _("_File"), MENUTREE_FILE, \
         _("_Edit"), MENUTREE_EDIT, \
@@ -219,6 +132,7 @@ static void menutree_build_shell(MenuTree *menu_tree, GtkMenuShell * shell, ...)
         _("_Help"), MENUTREE_HELP
 
 #define COPY_PASTE_MENU_ITEMS \
+        _("Select _All"), MENUTREE_EDIT_SELECT_ALL, \
         _("_Copy"), MENUTREE_EDIT_COPY, \
         _("_Paste"), MENUTREE_EDIT_PASTE, \
         _("Cop_y & Paste"), MENUTREE_EDIT_COPY_AND_PASTE, \
@@ -227,14 +141,25 @@ static void menutree_build_shell(MenuTree *menu_tree, GtkMenuShell * shell, ...)
 #define RESET_MENU_ITEMS \
         _("_Reset"), MENUTREE_EDIT_RESET, \
         _("Reset And C_lear"), MENUTREE_EDIT_RESET_AND_CLEAR
-        
+
 #define SHOW_MENU_BAR_ITEM \
         _("Show Menu_bar"), MENUTREE_VIEW_SHOW_MENUBAR
-        
-#define ENC_INPUT_ITEMS \
-        _("C_haracter Encoding"), MENUTREE_PREFERENCES_CHARACTER_ENCODING, \
-        _("_Input Methods"), MENUTREE_PREFERENCES_INPUT_METHODS
-        
+
+#define PREFS_ITEMS1 \
+        _("Select _Profile"), MENUTREE_PREFERENCES_SELECT_PROFILE, \
+        _("Select _Colour Scheme"), MENUTREE_PREFERENCES_SELECT_COLOUR_SCHEME, \
+        _("Select _Shortcuts Scheme"), MENUTREE_PREFERENCES_SELECT_SHORTCUTS, \
+        "_", MENUTREE_NULL_ID, \
+        _("_Edit Current Profile"), MENUTREE_PREFERENCES_EDIT_CURRENT_PROFILE, \
+        _("E_dit Current Colour Scheme"), \
+            MENUTREE_PREFERENCES_EDIT_CURRENT_COLOUR_SCHEME
+
+#define PREFS_ITEMS2 \
+        "_", MENUTREE_NULL_ID, \
+        _("Configuration _Manager"), MENUTREE_PREFERENCES_CONFIG_MANAGER, \
+        "_", MENUTREE_NULL_ID, \
+        NULL
+
 GtkMenu *menutree_submenu_from_id(MenuTree *mtree, MenuTreeID id)
 {
     GtkWidget *item = menutree_get_widget_for_id(mtree, id);
@@ -255,7 +180,7 @@ menutree_set_accel_path_for_submenu(MenuTree *mtree, MenuTreeID id,
 {
     GtkMenu *menu = menutree_submenu_from_id(mtree, id);
     char *accel_path;
-    
+
     if (!menu)
         return;
     accel_path = get_accel_path(mtree->shortcuts, menu_branch);
@@ -270,7 +195,7 @@ menutree_set_accel_path_for_item(MenuTree * tree, MenuTreeID id,
 {
     GtkWidget *item = tree->item_widgets[id];
     char *full_path;
-    
+
     if (!item)
         return;
     full_path = get_accel_path(tree->shortcuts, path_leaf);
@@ -312,19 +237,17 @@ void menutree_apply_shortcuts(MenuTree *tree, Options *shortcuts)
 {
     GtkMenu *submenu;
     char *accel_path;
-    
+
     tree->shortcuts = shortcuts;
     shortcuts_enable_signal_handler(FALSE);
     menutree_set_accel_path_for_submenu(tree, MENUTREE_FILE, "File");
     menutree_set_accel_path_for_submenu(tree, MENUTREE_EDIT, "Edit");
     menutree_set_accel_path_for_submenu(tree, MENUTREE_VIEW, "View");
-#ifdef HAVE_VTE_TERMINAL_SEARCH_SET_GREGEX
     menutree_set_accel_path_for_submenu(tree, MENUTREE_SEARCH, "Search");
-#endif
     menutree_set_accel_path_for_submenu(tree, MENUTREE_PREFERENCES,
             "Preferences");
     menutree_set_accel_path_for_submenu(tree, MENUTREE_HELP, "Help");
-    
+
     submenu = GTK_MENU(tree->new_win_profiles_menu);
     if (submenu)
     {
@@ -343,7 +266,7 @@ void menutree_apply_shortcuts(MenuTree *tree, Options *shortcuts)
         g_free(accel_path);
         gtk_menu_set_accel_group(submenu, tree->accel_group);
     }
-    
+
     /* Tabs have shortcuts set dynamically so set paths
      * for fixed items individually */
     submenu = menutree_submenu_from_id(tree, MENUTREE_TABS);
@@ -376,180 +299,12 @@ void menutree_apply_shortcuts(MenuTree *tree, Options *shortcuts)
     shortcuts_enable_signal_handler(TRUE);
 }
 
-#define MENUTREE_ENCODING_KEY "Encoding"
-#define MENUTREE_ENCODING_NULL "NULL"
-
-static GtkWidget *create_encoding_item(MenuTree *mtree,
-        const char *encoding_label, const char *encoding_data,
-        MenuTreeToggledHandler handler)
+/*
+static void submenu_destroy_handler(GtkWidget *menu, gpointer handle)
 {
-    GtkWidget *item = gtk_radio_menu_item_new_with_label(mtree->encodings_group,
-            encoding_label);
-
-    g_object_set_data_full(G_OBJECT(item), MENUTREE_ENCODING_KEY,
-                g_strdup(encoding_data), g_free);
-    g_signal_connect(item, "toggled", G_CALLBACK(handler), mtree->user_data);
-    gtk_widget_show(item);
-    return item;
-}
-
-static GtkWidget *add_encoding(MenuTree *mtree, const char *encoding_label,
-        const char *encoding_data, MenuTreeToggledHandler handler)
-{
-    GtkWidget *item = create_encoding_item(mtree,
-            encoding_label, encoding_data, handler);
-
-    gtk_menu_shell_append(GTK_MENU_SHELL(mtree->encodings), item);
-    mtree->encodings_group =
-        gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));
-    ++mtree->n_encodings;
-    return item;
-}
-
-static void create_encodings_menu(MenuTree *mtree,
-        MenuTreeToggledHandler handler)
-{
-    GtkWidget *item;
-
-    mtree->encodings = gtk_menu_new();
-    item = add_encoding(mtree, _("Default"), MENUTREE_ENCODING_NULL,
-            handler);
-    mtree->n_encodings = 0;    /* "Default" doesn't count */
-    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
-    item = gtk_separator_menu_item_new();
-    gtk_menu_shell_append(GTK_MENU_SHELL(mtree->encodings), item);
-    gtk_widget_show(item);
-    gtk_widget_set_sensitive(mtree->item_widgets
-                [MENUTREE_PREFERENCES_CHARACTER_ENCODING], TRUE);
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(mtree->item_widgets
-                [MENUTREE_PREFERENCES_CHARACTER_ENCODING]),
-            mtree->encodings);
-}
-
-void menutree_build_encodings_menu(MenuTree *mtree, char const **encodings,
-        MenuTreeToggledHandler handler)
-{
-    /* We skip first item in list, "Default" */
-    if (encodings && encodings[1])
-    {
-        int n;
-
-        create_encodings_menu(mtree, handler);
-        for (n = 1; encodings[n]; ++n)
-        {
-            add_encoding(mtree, encodings[n], encodings[n], handler);
-        }
-    }
-    else
-    {
-        gtk_widget_set_sensitive(mtree->item_widgets
-                    [MENUTREE_PREFERENCES_CHARACTER_ENCODING], FALSE);
-    }
-}
-
-const char *menutree_encoding_from_widget(GtkCheckMenuItem *item)
-{
-    const char *encoding = g_object_get_data(G_OBJECT(item),
-            MENUTREE_ENCODING_KEY);
-
-    if (!strcmp(encoding, MENUTREE_ENCODING_NULL))
-        return NULL;
-    return encoding;
-}
-
-void menutree_add_encoding(MenuTree *mtree, const char *encoding,
-        MenuTreeToggledHandler handler)
-{
-    if (!mtree->encodings)
-    {
-        create_encodings_menu(mtree, handler);
-    }
-    add_encoding(mtree, encoding, encoding, handler);
-}
-
-static GtkWidget *menutree_find_encoding(MenuTree *mtree,
-        const char *encoding, int *position)
-{
-    GList *link;
-    int n = 0;
-
-    if (!position)
-        position = &n;
-    if (!mtree->encodings)
-    {
-        *position = -1;
-        return NULL;
-    }
-    link = gtk_container_get_children(GTK_CONTAINER(mtree->encodings));
-    if (!encoding)
-    {
-        if (mtree->encodings)
-        {
-            *position = 0;
-            return link->data;
-        }
-    }
-    while (++n, (link = g_list_next(link)) != NULL)
-    {
-        if (n == 1) continue; /* Skip separator */
-        if (!strcmp(menutree_encoding_from_widget(link->data), encoding))
-        {
-            *position = n;
-            return link->data;
-        }
-    }
-    g_critical(_("Encoding '%s' not found in menu"), encoding);
-    *position = -1;
-    return NULL;
-}
-
-void menutree_remove_encoding(MenuTree *mtree, const char *encoding)
-{
-    GtkWidget *item = menutree_find_encoding(mtree, encoding, NULL);
-
-    if (item)
-    {
-        gtk_widget_destroy(item);
-        if (!--mtree->n_encodings)
-        {
-            gtk_widget_destroy(mtree->encodings);
-            mtree->encodings = NULL;
-            mtree->encodings_group = NULL;
-            gtk_widget_set_sensitive(mtree->item_widgets
-                        [MENUTREE_PREFERENCES_CHARACTER_ENCODING], FALSE);
-        }
-        /* else... we never destroy first item in group, so it should be safe
-         * to leave encodings_group unchanged */
-    }
-}
-
-void menutree_change_encoding(MenuTree *mtree, const char *old_encoding,
-        const char *new_encoding, MenuTreeToggledHandler handler)
-{
-    int position;
-    GtkWidget *item = menutree_find_encoding(mtree, old_encoding, &position);
-
-    if (item)
-    {
-        gboolean state =
-            gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(item));
-
-        gtk_widget_destroy(item);
-        item = create_encoding_item(mtree, new_encoding, new_encoding, handler);
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), state);
-        gtk_menu_shell_insert(GTK_MENU_SHELL(mtree->encodings), item, position);
-    }
-}
-
-void menutree_select_encoding(MenuTree *mtree, const char *encoding)
-{
-    GtkWidget *item = menutree_find_encoding(mtree, encoding, NULL);
-
-    if (item)
-    {
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
-    }
+    g_debug("Destroying submenu %p", menu);
 }
+*/
 
 /* Creates top-level menubar or popup menu with submenus */
 static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
@@ -571,22 +326,31 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
     }
 
     submenu = gtk_menu_new();
+    /*
+    g_debug("Creating File submenu %p", submenu);
+    g_signal_connect(submenu, "destroy",
+            G_CALLBACK(submenu_destroy_handler), NULL);
+    */
     menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
         _("_New Window"), MENUTREE_FILE_NEW_WINDOW,
         _("New _Tab"), MENUTREE_FILE_NEW_TAB,
         _("New _Window With Profile"), MENUTREE_FILE_NEW_WINDOW_WITH_PROFILE,
         _("New Tab With _Profile"), MENUTREE_FILE_NEW_TAB_WITH_PROFILE,
         _("C_lose Tab"), MENUTREE_FILE_CLOSE_TAB,
-        _("_Close Window"), MENUTREE_FILE_CLOSE_WINDOW, NULL);
+        _("_Close Window"), MENUTREE_FILE_CLOSE_WINDOW,
+        _("_Save Session..."), MENUTREE_FILE_SAVE_SESSION,
+        NULL);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_FILE]), submenu);
-    
+
     menu_tree->new_win_profiles_menu = gtk_menu_new();
     menutree_build_shell(menu_tree,
             GTK_MENU_SHELL(menu_tree->new_win_profiles_menu),
             _("Profiles"), MENUTREE_FILE_NEW_WINDOW_WITH_PROFILE_HEADER,
             "_", MENUTREE_NULL_ID,
             NULL);
+    gtk_widget_set_sensitive(menutree_get_widget_for_id(menu_tree,
+                MENUTREE_FILE_NEW_WINDOW_WITH_PROFILE_HEADER), FALSE);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_FILE_NEW_WINDOW_WITH_PROFILE]),
             menu_tree->new_win_profiles_menu);
@@ -596,6 +360,8 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
             _("Profiles"), MENUTREE_FILE_NEW_TAB_WITH_PROFILE_HEADER,
             "_", MENUTREE_NULL_ID,
             NULL);
+    gtk_widget_set_sensitive(menutree_get_widget_for_id(menu_tree,
+                MENUTREE_FILE_NEW_TAB_WITH_PROFILE_HEADER), FALSE);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_FILE_NEW_TAB_WITH_PROFILE]),
             menu_tree->new_tab_profiles_menu);
@@ -616,6 +382,7 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
         SHOW_MENU_BAR_ITEM,
         _("_Always Show Tab Bar"), MENUTREE_VIEW_SHOW_TAB_BAR,
         _("_Full Screen"), MENUTREE_VIEW_FULLSCREEN,
+        _("_Borderless"), MENUTREE_VIEW_BORDERLESS,
         "_", MENUTREE_NULL_ID,
         _("Zoom _In"), MENUTREE_VIEW_ZOOM_IN,
         _("Zoom _Out"), MENUTREE_VIEW_ZOOM_OUT,
@@ -625,13 +392,14 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
         _("Scroll _Down One Line"), MENUTREE_VIEW_SCROLL_DOWN,
         _("Scroll Up One _Page"), MENUTREE_VIEW_SCROLL_PAGE_UP,
         _("Scroll Do_wn One Page"), MENUTREE_VIEW_SCROLL_PAGE_DOWN,
+        _("Scroll Up One _Half Page"), MENUTREE_VIEW_SCROLL_HALF_PAGE_UP,
+        _("Scroll Down One Hal_f Page"), MENUTREE_VIEW_SCROLL_HALF_PAGE_DOWN,
         _("Scroll To _Top"), MENUTREE_VIEW_SCROLL_TO_TOP,
         _("Scroll To _Bottom"), MENUTREE_VIEW_SCROLL_TO_BOTTOM,
         NULL);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_VIEW]), submenu);
 
-#ifdef HAVE_VTE_TERMINAL_SEARCH_SET_GREGEX
     submenu = gtk_menu_new();
     menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
         _("_Find..."), MENUTREE_SEARCH_FIND,
@@ -640,22 +408,13 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
         NULL);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_SEARCH]), submenu);
-#endif
 
     submenu = gtk_menu_new();
     menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-        _("Select _Profile"), MENUTREE_PREFERENCES_SELECT_PROFILE,
-        _("Select _Colour Scheme"), MENUTREE_PREFERENCES_SELECT_COLOUR_SCHEME,
-        _("Select _Shortcuts Scheme"), MENUTREE_PREFERENCES_SELECT_SHORTCUTS,
-        "_", MENUTREE_NULL_ID,
-        _("_Edit Current Profile"), MENUTREE_PREFERENCES_EDIT_CURRENT_PROFILE,
-        _("E_dit Current Colour Scheme"),
-            MENUTREE_PREFERENCES_EDIT_CURRENT_COLOUR_SCHEME,
-        "_", MENUTREE_NULL_ID,
-        _("Configuration _Manager"), MENUTREE_PREFERENCES_CONFIG_MANAGER,
-        "_", MENUTREE_NULL_ID,
-        ENC_INPUT_ITEMS,
-        NULL);
+        PREFS_ITEMS1,
+        _("Edi_t Current Shortcuts Scheme"),
+            MENUTREE_PREFERENCES_EDIT_CURRENT_SHORTCUTS_SCHEME,
+        PREFS_ITEMS2);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
             [MENUTREE_PREFERENCES]), submenu);
 
@@ -687,21 +446,24 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 static void menutree_build_short_popup(MenuTree *menu_tree, Options *shortcuts,
         GType menu_type)
 {
+    (void) menu_type;
     menu_tree->top_level = gtk_menu_new();
     menutree_build_shell(menu_tree, GTK_MENU_SHELL(menu_tree->top_level),
         URI_MENU_ITEMS,
         COPY_PASTE_MENU_ITEMS,
         RESET_MENU_ITEMS,
         SHOW_MENU_BAR_ITEM,
-        ENC_INPUT_ITEMS,
         NULL);
     menutree_apply_shortcuts(menu_tree, shortcuts);
 }
 
 static void menutree_destroy(MenuTree * tree)
 {
+    //g_debug("Destroying menu tree %p", tree);
     if (tree->deleted_handler)
         tree->deleted_handler(tree, tree->deleted_data);
+    if (tree->tabs)
+        g_list_free(tree->tabs);
     g_free(tree);
 }
 
@@ -709,6 +471,7 @@ static void menutree_destroy_widget_handler(GObject * obj, MenuTree * tree)
 {
     (void) obj;
 
+    //g_debug("Menu %p being destroyed", obj);
     tree->top_level = NULL;
     /* tree is no good any more so destroy it */
     menutree_destroy(tree);
@@ -723,6 +486,12 @@ static MenuTree *menutree_new_common(Options *shortcuts,
         gboolean disable_tab_shortcuts, gpointer user_data)
 {
     MenuTree *tree = g_new0(MenuTree, 1);
+    int n;
+
+    for (n = 0; n < MENUTREE_NUM_IDS; ++n)
+    {
+        tree->item_widgets[n] = NULL;
+    }
 
     tree->user_data = user_data;
     tree->accel_group = accel_group;
@@ -743,7 +512,7 @@ MenuTree *menutree_new(Options *shortcuts, GtkAccelGroup *accel_group,
     gboolean disable_tab_shortcuts, gpointer user_data)
 {
     MenuTree *tree = NULL;
-    
+
     if (!filled_labels)
     {
         int n;
@@ -753,6 +522,10 @@ MenuTree *menutree_new(Options *shortcuts, GtkAccelGroup *accel_group,
     }
     tree = menutree_new_common(shortcuts, accel_group, menu_type,
         menutree_build, disable_shortcuts, disable_tab_shortcuts, user_data);
+    /*
+    g_debug("Created menu %p of type %s", tree->top_level,
+            menu_type == GTK_TYPE_MENU_BAR ? "bar" : "popup");
+    */
     filled_labels = TRUE;
     return tree;
 }
@@ -761,10 +534,12 @@ MenuTree *menutree_new_short_popup(Options *shortcuts,
         GtkAccelGroup *accel_group, gboolean disable_shortcuts,
         gpointer user_data)
 {
-    return menutree_new_common(shortcuts, accel_group, GTK_TYPE_MENU,
+    MenuTree *tree = menutree_new_common(shortcuts, accel_group, GTK_TYPE_MENU,
         menutree_build_short_popup, disable_shortcuts, FALSE, user_data);
+    //g_debug("Created short popup menu %p", tree->top_level);
+    return tree;
 }
-    
+
 void menutree_delete(MenuTree * tree)
 {
     g_return_if_fail(tree != NULL);
@@ -834,7 +609,7 @@ static GtkWidget *menutree_tab_menu_item_new(GtkMenuShell *menu,
 GtkWidget *menutree_add_tab_at_position(MenuTree * tree, const char *title,
         int position)
 {
-    GtkMenuShell *submenu = menutree_get_submenu_at_id(tree, MENUTREE_TABS); 
+    GtkMenuShell *submenu = menutree_get_submenu_at_id(tree, MENUTREE_TABS);
     GtkWidget *menu_item = menutree_tab_menu_item_new(submenu, title);
 
     if (position == -1)
@@ -857,7 +632,7 @@ GtkWidget *menutree_add_tab_at_position(MenuTree * tree, const char *title,
 static void menu_item_change_label(GtkMenuItem *item, const char *label)
 {
     GtkWidget *inner_item = gtk_bin_get_child(GTK_BIN(item));
-    
+
     if (GTK_IS_LABEL(inner_item))
     {
         gtk_label_set_text_with_mnemonic(GTK_LABEL(inner_item), label);
@@ -865,12 +640,12 @@ static void menu_item_change_label(GtkMenuItem *item, const char *label)
     else if (GTK_IS_CONTAINER(inner_item))
     {
         GList *link;
-        
+
         for (link = gtk_container_get_children(GTK_CONTAINER(inner_item));
                 link; link = g_list_next(link))
         {
             GtkWidget *child = link->data;
-            
+
             if (GTK_IS_LABEL(child))
             {
                 gtk_label_set_text_with_mnemonic(GTK_LABEL(child), label);
@@ -890,6 +665,7 @@ inline static void menutree_change_label(MenuTree *tree, MenuTreeID id,
 GtkWidget *menutree_change_tab_title(MenuTree * tree,
     GtkWidget * menu_item, const char *title)
 {
+    (void) tree;
     menu_item_change_label(GTK_MENU_ITEM(menu_item), title);
     return menu_item;
 }
@@ -928,6 +704,11 @@ void menutree_set_fullscreen_active(MenuTree *tree, gboolean active)
     menutree_set_toggle(tree, MENUTREE_VIEW_FULLSCREEN, active);
 }
 
+void menutree_set_borderless_active(MenuTree *tree, gboolean active)
+{
+    menutree_set_toggle(tree, MENUTREE_VIEW_BORDERLESS, active);
+}
+
 extern  void multi_win_new_tab_action(gpointer win);
 
 gulong menutree_named_signal_connect_data(MenuTree * tree, MenuTreeID id,
@@ -954,12 +735,6 @@ void menutree_set_show_item(MenuTree * tree, MenuTreeID id, gboolean show)
         gtk_widget_hide(item);
 }
 
-void menutree_attach_im_submenu(MenuTree *tree, GtkWidget *submenu)
-{
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(tree->item_widgets
-            [MENUTREE_PREFERENCES_INPUT_METHODS]), submenu);
-}
-
 void menutree_disable_shortcuts(MenuTree *tree, gboolean disable)
 {
     int n;
@@ -999,5 +774,5 @@ void menutree_disable_tab_shortcuts(MenuTree *tree, gboolean disable)
     tree->disable_tab_shortcuts = disable;
     menutree_apply_tab_shortcuts(tree);
 }
-    
+
 /* vi:set sw=4 ts=4 et cindent cino= */
