@@ -1,8 +1,8 @@
 #ifndef MENUTREE_H
 #define MENUTREE_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,14 +30,18 @@
 typedef enum {
     MENUTREE_NULL_ID = -1,
 
+    MENUTREE_SSH_HOST,
     MENUTREE_OPEN_IN_BROWSER,
     MENUTREE_OPEN_IN_MAILER,
+    MENUTREE_OPEN_IN_FILER,
+    MENUTREE_VOIP_CALL,
     MENUTREE_COPY_URI,
     MENUTREE_URI_SEPARATOR,
 
     MENUTREE_FILE,
     MENUTREE_EDIT,
     MENUTREE_VIEW,
+    MENUTREE_SEARCH,
     MENUTREE_PREFERENCES,
     MENUTREE_TABS,
     MENUTREE_HELP,
@@ -50,7 +54,9 @@ typedef enum {
     MENUTREE_FILE_NEW_TAB_WITH_PROFILE_HEADER,
     MENUTREE_FILE_CLOSE_TAB,
     MENUTREE_FILE_CLOSE_WINDOW,
+    MENUTREE_FILE_SAVE_SESSION,
 
+    MENUTREE_EDIT_SELECT_ALL,
     MENUTREE_EDIT_COPY,
     MENUTREE_EDIT_PASTE,
     MENUTREE_EDIT_COPY_AND_PASTE,
@@ -62,11 +68,22 @@ typedef enum {
     MENUTREE_VIEW_SHOW_MENUBAR,
     MENUTREE_VIEW_SHOW_TAB_BAR,
     MENUTREE_VIEW_FULLSCREEN,
+    MENUTREE_VIEW_BORDERLESS,
     MENUTREE_VIEW_ZOOM_IN,
     MENUTREE_VIEW_ZOOM_OUT,
     MENUTREE_VIEW_ZOOM_NORM,
     MENUTREE_VIEW_SCROLL_UP,
     MENUTREE_VIEW_SCROLL_DOWN,
+    MENUTREE_VIEW_SCROLL_PAGE_UP,
+    MENUTREE_VIEW_SCROLL_PAGE_DOWN,
+    MENUTREE_VIEW_SCROLL_HALF_PAGE_UP,
+    MENUTREE_VIEW_SCROLL_HALF_PAGE_DOWN,
+    MENUTREE_VIEW_SCROLL_TO_TOP,
+    MENUTREE_VIEW_SCROLL_TO_BOTTOM,
+
+    MENUTREE_SEARCH_FIND,
+    MENUTREE_SEARCH_FIND_NEXT,
+    MENUTREE_SEARCH_FIND_PREVIOUS,
 
     MENUTREE_PREFERENCES_PROFILES,
     MENUTREE_PREFERENCES_SELECT_PROFILE,
@@ -74,10 +91,12 @@ typedef enum {
     MENUTREE_PREFERENCES_SELECT_SHORTCUTS,
     MENUTREE_PREFERENCES_EDIT_CURRENT_PROFILE,
     MENUTREE_PREFERENCES_EDIT_CURRENT_COLOUR_SCHEME,
+    MENUTREE_PREFERENCES_EDIT_CURRENT_SHORTCUTS_SCHEME,
     MENUTREE_PREFERENCES_CONFIG_MANAGER,
-    MENUTREE_PREFERENCES_CHARACTER_ENCODING,
-    MENUTREE_PREFERENCES_INPUT_METHODS,
 
+    MENUTREE_TABS_DETACH_TAB,
+    MENUTREE_TABS_CLOSE_TAB,
+    MENUTREE_TABS_CLOSE_OTHER_TABS,
     MENUTREE_TABS_NAME_TAB,
     MENUTREE_TABS_PREVIOUS_TAB,
     MENUTREE_TABS_NEXT_TAB,
@@ -90,7 +109,7 @@ typedef enum {
 
     MENUTREE_NUM_IDS,
 
-    MENUTREE_TABS_FIRST_FIXED = MENUTREE_TABS_NAME_TAB,
+    MENUTREE_TABS_FIRST_FIXED = MENUTREE_TABS_DETACH_TAB,
     MENUTREE_TABS_LAST_FIXED = MENUTREE_TABS_MOVE_TAB_RIGHT + 1,
                                 /* +1 for separator */
     MENUTREE_TABS_FIRST_DYNAMIC =
@@ -110,9 +129,6 @@ struct MenuTree {
     GList *tabs;    /* List of GtkMenuItem widgets */
     int ntabs;
     Options *shortcuts;
-    GtkWidget *encodings;    /* Encodings submenu */
-    GSList *encodings_group;
-    int n_encodings;
     gboolean disable_shortcuts;
     gboolean disable_tab_shortcuts;
     GtkWidget *new_win_profiles_menu;
@@ -134,28 +150,6 @@ MenuTree *menutree_new_short_popup(Options *shortcuts,
         GtkAccelGroup *accel_group, gboolean disable_shortcuts,
         gpointer user_data);
 
-/* A "raw" handler for "toggled" signals on encodings items. The user_data
- * argument will be as passed to menutree_new. The client should work out
- * whether the widget is being toggled on or off and use
- * menutree_encoding_from_widget to get the encoding name. */
-typedef void (*MenuTreeToggledHandler)(GtkCheckMenuItem *, gpointer);
-
-void menutree_build_encodings_menu(MenuTree *, char const **encodings,
-        MenuTreeToggledHandler);
-
-const char *menutree_encoding_from_widget(GtkCheckMenuItem *);
-
-void menutree_add_encoding(MenuTree *, const char *encoding,
-        MenuTreeToggledHandler);
-
-void menutree_remove_encoding(MenuTree *, const char *encoding);
-
-void menutree_change_encoding(MenuTree *, const char *old_encoding,
-        const char *new_encoding, MenuTreeToggledHandler);
-
-void menutree_select_encoding(MenuTree *, const char *encoding);
-
-
 void menutree_delete(MenuTree *);
 
 /* Gets the widget at the top-level (menu bar or popup menu) */
@@ -202,6 +196,7 @@ GtkWidget *menutree_change_tab_title(MenuTree * tree,
 void menutree_set_show_menu_bar_active(MenuTree * tree, gboolean active);
 void menutree_set_show_tab_bar_active(MenuTree *tree, gboolean active);
 void menutree_set_fullscreen_active(MenuTree *tree, gboolean active);
+void menutree_set_borderless_active(MenuTree *tree, gboolean active);
 
 gulong menutree_named_signal_connect_data(MenuTree * tree, MenuTreeID id,
     const char *signame, GCallback handler, gpointer user_data,
@@ -246,9 +241,6 @@ menutree_signal_connect_swapped(MenuTree * tree, MenuTreeID id,
 
 void menutree_set_show_item(MenuTree * tree, MenuTreeID id, gboolean show);
 
-/* Attach an Input Methods submenu for the current tab */
-void menutree_attach_im_submenu(MenuTree *tree, GtkWidget *submenu);
-
 void menutree_apply_shortcuts(MenuTree *tree, Options *shortcuts);
 
 /* Use with gtk_container_foreach to find the group of the last radio menu
@@ -261,6 +253,7 @@ void menutree_remove_tab(MenuTree * tree, GtkWidget * menu_item);
 
 inline static void menutree_select_tab(MenuTree * tree, GtkWidget * menu_item)
 {
+    (void) tree;
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), TRUE);
 }
 
