@@ -2,7 +2,7 @@
 #define MULTITAB_H
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@
 #include "menutree.h"
 #include "options.h"
 
-#define HAVE_COMPOSITE GTK_CHECK_VERSION(2, 10, 0)
-
 typedef struct MultiTab MultiTab;
 typedef struct MultiWin MultiWin;
 
@@ -54,6 +52,9 @@ typedef void (*MultiWinMenuSignalConnector) (MultiWin * win);
 
 /* Called when a window wants to know what geometry hints to use for a child
  * widget; the user_data is the data returned by MultiTabFiller's new_user_data.
+ * The geom should be filled in with the values for the active widget only;
+ * the caling code will work out what it has to add for the notebook, scrollbar
+ * and window decorations etc.
  */
 typedef void (*MultiWinGeometryFunc) (gpointer user_data, GdkGeometry * geom,
     GdkWindowHints * hints);
@@ -75,10 +76,10 @@ typedef void (*MultiTabSelectionHandler) (gpointer user_data, MultiTab * tab);
 
 /* Called when a tab is dragged to a new window; should be used to try to make
  * sure page is same size as other tabs in new window and to update references.
- * old_win_destroyed is TRUE if the tab's previous window was destroyed.
+ * old_win is NULL if the tab's previous window was destroyed.
  */
 typedef void (*MultiTabToNewWindowHandler)(MultiWin *win, MultiTab *tab,
-        gboolean old_win_destroyed);
+        MultiWin *old_win);
 
 /* Called when the zoom factor is changed */
 typedef void (*MultiWinZoomHandler)(gpointer user_data, double zoom_factor,
@@ -88,23 +89,29 @@ typedef void (*MultiWinZoomHandler)(gpointer user_data, double zoom_factor,
 typedef void (*MultiWinGetDisableMenuShortcuts)(gpointer user_data,
     gboolean *general, gboolean *tabs);
 
-/* As number of tabs and tab position can be set by user we need another
- * function to get these values */
-typedef void (*MultiWinInitialTabs)(gpointer user_data,
-        GtkPositionType *p_pos, int *p_num);
+/* As tab position can be set by user we need another function to get this */
+typedef GtkPositionType(*MultiWinGetTabPos)(gpointer user_data);
 
-/* A handler for delete-event */
-typedef void (*MultiWinDeleteHandler)(GtkWidget *, GdkEvent *, MultiWin *win);
+/* Called when a window or tab is about to be closed. If it's a tab, event is
+ * NULL and data is the tab's user_data. If event is non-NULL data is a
+ * MultiWin *. event is not necessarily a valid event, don't dereference it
+ * even if non-NULL.
+ * Return FALSE to close, TRUE to keep open. */
+typedef gboolean (*MultiWinDeleteHandler)(GtkWidget *, GdkEvent *,
+        gpointer data);
 
 /* Return whether to show close buttons in tabs */
 typedef gboolean (*MultiTabGetShowCloseButton)(gpointer user_data);
 
 /* Needed externally */
-MultiWinGetDisableMenuShortcuts multi_win_get_disable_menu_shortcuts;
+extern MultiWinGetDisableMenuShortcuts multi_win_get_disable_menu_shortcuts;
 
 /* Whether to open a new tab adjacent to current one */
 typedef gboolean (*MultiTabGetNewTabAdjacent)(gpointer user_data);
 
+/* Connects signals after a new tab has been shown */
+typedef void (*MultiTabConnectMiscSignals)(gpointer user_data);
+
 /* Call to set up function hooks. See MultiTabFiller etc above.
  * menu_signal_connector is called each time a new window is created to give
  * the client a chance to connect its signal handlers; each handler will
@@ -114,10 +121,9 @@ multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
     MultiWinMenuSignalConnector menu_signal_connector,
     MultiWinGeometryFunc, MultiWinSizeFunc, MultiWinDefaultSizeFunc,
     MultiTabToNewWindowHandler,
-    MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs,
+    MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinGetTabPos,
     MultiWinDeleteHandler, MultiTabGetShowCloseButton,
-    MultiTabGetNewTabAdjacent
-    );
+    MultiTabGetNewTabAdjacent, MultiTabConnectMiscSignals);
 
 /* Register a MultiTabSelectionHandler (see above) */
 void
@@ -130,11 +136,7 @@ void multi_tab_delete(MultiTab *);
 
 GtkWidget *multi_tab_get_widget(MultiTab *);
 
-const char *multi_tab_get_display_name(MultiTab *tab);
-
-void multi_tab_set_icon_title(MultiTab *, const char *);
-
-/* Sets the title which is used to build the actaul title from title_template.
+/* Sets the title which is used to build the actual title from title_template.
  */
 void multi_tab_set_window_title(MultiTab *, const char *);
 
@@ -150,9 +152,7 @@ void multi_tab_set_title_template_locked(MultiTab *, gboolean);
 /* Not the full title */
 const char *multi_tab_get_window_title(MultiTab *);
 
-const char *multi_tab_get_icon_title(MultiTab *);
-
-void multi_tab_popup_menu(MultiTab * tab, guint button, guint32 event_time);
+void multi_tab_popup_menu_at_pointer(MultiTab * tab);
 
 gpointer multi_tab_get_user_data(MultiTab *);
 
@@ -184,12 +184,6 @@ void multi_tab_move_to_position(MultiTab *tab, int position, gboolean reorder);
 /* Move tab to a different window */
 void multi_tab_move_to_new_window(MultiWin *win, MultiTab *tab, int position);
 
-/* Returns NULL if pointer not over one of our tabs. x and y are absolute
- * coordinates from mouse event. Note that when there are multiple tabs this
- * returns tab whose label spans pointer position, not necessarily the one
- * whose main page widget is under the pointer */
-MultiTab *multi_tab_get_tab_under_pointer(int x, int y);
-
 /* widget is the top-level child of the notebook, as would be passed in a drag
  * received event for a GtkNotebook dragged tab.
  */
@@ -201,7 +195,9 @@ void multi_tab_cancel_attention(MultiTab *tab);
 
 void multi_tab_add_close_button(MultiTab *tab);
 void multi_tab_remove_close_button(MultiTab *tab);
-void multi_tab_set_status_stock(MultiTab *tab, const char *stock);
+void multi_tab_set_status_icon_name(MultiTab *tab, const char *name);
+
+void multi_tab_set_middle_click_tab_action(MultiTab *tab, int action);
 
 /* In following functions a zoom_index of -1 means default */
 
@@ -215,31 +211,28 @@ typedef enum {
 void multi_win_set_role_prefix(const char *role_prefix);
 
 /* Create a new window with default settings, adding it to main list */
-MultiWin *multi_win_new_full(const char *display_name,
-        Options *shortcuts, int zoom_index,
+MultiWin *multi_win_new_full(Options *shortcuts, int zoom_index,
         gpointer user_data_template, const char *geom,
-        MultiWinSizing sizing, int numtabs, GtkPositionType tab_pos,
-        gboolean always_show_tabs);
+        MultiWinSizing sizing, GtkPositionType tab_pos, gboolean borderless,
+        gboolean always_show_tabs, gboolean add_tab_button);
 
-inline static MultiWin *multi_win_new_with_geom(const char *display_name,
-        Options *shortcuts,
+inline static MultiWin *multi_win_new_with_geom(Options *shortcuts,
         int zoom_index, gpointer user_data_template,
-        const char *geom, int numtabs, GtkPositionType tab_pos,
-        gboolean always_show_tabs)
+        const char *geom, GtkPositionType tab_pos, gboolean borderless,
+        gboolean always_show_tabs, gboolean add_tab_button)
 {
-    return multi_win_new_full(display_name, shortcuts, zoom_index,
+    return multi_win_new_full(shortcuts, zoom_index,
                   user_data_template, geom, MULTI_WIN_DEFAULT_SIZE,
-                  numtabs, tab_pos, always_show_tabs);
+                  tab_pos, borderless, always_show_tabs, add_tab_button);
 }
 
-inline static MultiWin *multi_win_new(const char *display_name,
-        Options *shortcuts, int zoom_index,
-        gpointer user_data_template, int numtabs, GtkPositionType tab_pos,
-        gboolean always_show_tabs)
+inline static MultiWin *multi_win_new(Options *shortcuts, int zoom_index,
+        gpointer user_data_template, GtkPositionType tab_pos, gboolean borderless,
+        gboolean always_show_tabs, gboolean add_tab_button)
 {
-    return multi_win_new_full(display_name, shortcuts, zoom_index,
+    return multi_win_new_full(shortcuts, zoom_index,
                   user_data_template, NULL, MULTI_WIN_DEFAULT_SIZE,
-                  numtabs, tab_pos, always_show_tabs);
+                  tab_pos, borderless, always_show_tabs, add_tab_button);
 }
 
 /* Creates a new window that's the same as the old one except with a different
@@ -248,39 +241,36 @@ inline static MultiWin *multi_win_new(const char *display_name,
 MultiWin *multi_win_clone(MultiWin *old,
         gpointer user_data_template, gboolean always_show_tabs);
 
-inline static MultiWin *multi_win_new_fullscreen(const char *display_name,
-        Options *shortcuts,
+inline static MultiWin *multi_win_new_fullscreen(Options *shortcuts,
         int zoom_index, gpointer user_data_template,
-        int numtabs, GtkPositionType tab_pos,
-        gboolean always_show_tabs)
+        GtkPositionType tab_pos, gboolean borderless,
+        gboolean always_show_tabs, gboolean add_tab_button)
 {
-    return multi_win_new_full(display_name, shortcuts, zoom_index,
+    return multi_win_new_full(shortcuts, zoom_index,
                   user_data_template, NULL, MULTI_WIN_FULL_SCREEN,
-                  numtabs, tab_pos, always_show_tabs);
+                  tab_pos, borderless, always_show_tabs, add_tab_button);
 }
 
-inline static MultiWin *multi_win_new_maximised(const char *display_name,
-        Options *shortcuts,
+inline static MultiWin *multi_win_new_maximised(Options *shortcuts,
         int zoom_index, gpointer user_data_template,
-        int numtabs, GtkPositionType tab_pos,
-        gboolean always_show_tabs)
+        GtkPositionType tab_pos, gboolean borderless,
+        gboolean always_show_tabs, gboolean add_tab_button)
 {
-    return multi_win_new_full(display_name, shortcuts, zoom_index,
+    return multi_win_new_full(shortcuts, zoom_index,
                   user_data_template, NULL, MULTI_WIN_MAXIMISED,
-                  numtabs, tab_pos, always_show_tabs);
+                  tab_pos, borderless, always_show_tabs, add_tab_button);
 }
 
 /* Create a new window without a new child tab, ready to have an existing
  * tab moved to it. Window isn't shown yet because we don't know how big we
  * want it to be until it contains a tab. */
-MultiWin *multi_win_new_blank(const char *display_name,
-        Options *shortcuts, int zoom_index,
+MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
         gboolean disable_menu_shortcuts, gboolean disable_tab_shortcuts,
-        GtkPositionType tab_pos, gboolean always_show_tabs);
+        GtkPositionType tab_pos, gboolean always_show_tabs,
+        gboolean add_tab_button);
 
 /* Creates a new "blank" window ready for a dragged tab at given coords */
-MultiWin *multi_win_new_for_tab(const char *display_name, int x, int y,
-        MultiTab *tab);
+MultiWin *multi_win_new_for_tab(int x, int y, MultiTab *tab);
 
 void multi_win_show(MultiWin *win);
 
@@ -289,9 +279,7 @@ void multi_win_show(MultiWin *win);
  * windows are destroyed it calls gtk_main_quit() */
 void multi_win_delete(MultiWin *);
 
-void
-multi_win_set_geometry_hints(MultiWin * win, GtkWidget * child,
-    GdkGeometry * geometry, GdkWindowHints geom_mask);
+void multi_win_set_borderless(MultiWin *win, gboolean borderless);
 
 void multi_win_set_fullscreen(MultiWin *win, gboolean fullscreen);
 
@@ -301,6 +289,8 @@ gboolean multi_win_is_fullscreen(MultiWin *win);
 
 gboolean multi_win_is_maximised(MultiWin *win);
 
+gboolean multi_win_is_borderless(MultiWin *win);
+
 int multi_win_get_zoom_index(MultiWin *win);
 
 double multi_win_get_zoom_factor(MultiWin *win);
@@ -347,8 +337,7 @@ MenuTree *multi_win_get_short_popup_menu(MultiWin * win);
 
 Options *multi_win_get_shortcut_scheme(MultiWin * win);
 
-/* reapply is for forcing an update of the current scheme */
-void multi_win_set_shortcut_scheme(MultiWin * win, Options *, gboolean reapply);
+void multi_win_set_shortcut_scheme(MultiWin * win, Options *);
 
 GtkAccelGroup *multi_win_get_accel_group(MultiWin * win);
 
@@ -369,10 +358,6 @@ typedef enum {
 MultiWinScrollBar_Position multi_win_set_scroll_bar_position(MultiWin * win,
     MultiWinScrollBar_Position new_pos);
 
-/* Returns the window under the pointer or NULL if the window isn't a terminal
- * window owned by this app */
-MultiWin *multi_win_get_win_under_pointer(void);
-
 /* Make sure this win's current tab claims focus for this win */
 void multi_win_restore_focus(MultiWin *win);
 
@@ -397,6 +382,10 @@ gboolean multi_win_get_always_show_tabs(MultiWin *win);
 
 void multi_win_set_always_show_tabs(MultiWin *win, gboolean show);
 
+gboolean multi_win_get_show_add_tab_button(MultiWin *win);
+
+void multi_win_set_show_add_tab_button(MultiWin *win, gboolean show);
+
 /* List of all known windows - treat as read-only */
 extern GList *multi_win_all;
 
@@ -419,12 +408,25 @@ gboolean multi_win_get_title_template_locked(MultiWin *win);
 /* Whether window is managed by a compositor */
 gboolean multi_win_composite(MultiWin *win);
 
-const char *multi_win_get_display_name(MultiWin *win);
-
 const char *multi_win_get_shortcuts_scheme_name(MultiWin *win);
 
 guint multi_win_get_num_tabs(MultiWin *win);
 
+/* Parses a geometry string and returns TRUE if successful. If sizes
+ * aren't given their respective outputs are set to 0. xy is updated to indicate
+ * whether x and y were present.
+ */
+gboolean multi_win_parse_geometry(const char *geom,
+        int *width, int *height, int *x, int *y, gboolean *xy);
+
+/* tab may be NULL to use the currently active tab */
+void multi_win_set_initial_geometry(MultiWin *win, const char *geom,
+        MultiTab *tab);
+
+/* tab may be NULL to use the currently active tab */
+void multi_win_apply_new_geometry(MultiWin *win, int columns, int rows,
+        MultiTab *tab);
+
 #endif /* MULTITAB_H */
 
 /* vi:set sw=4 ts=4 et cindent cino= */
