@@ -1,6 +1,6 @@
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 */
 
 
-#include "display.h"
 #include "dlg.h"
 #include "globalopts.h"
 #include "optsdbus.h"
@@ -49,16 +48,13 @@
 
 #ifdef ROXTERM_CAPPLET
 
-static gboolean optsdbus_read_args(DBusMessage *message,
-        char RTDBUS_ARG_CONST **arg, char RTDBUS_ARG_CONST **display,
+static gboolean optsdbus_read_args(DBusMessage *message, char const **arg,
         DBusError *perror, DBusMessage **preply_error)
 {
     gboolean result = arg ? dbus_message_get_args(message, perror,
                 DBUS_TYPE_STRING, arg,
-                DBUS_TYPE_STRING, display,
-                DBUS_TYPE_INVALID) : 
+                DBUS_TYPE_INVALID) :
                 dbus_message_get_args(message, perror,
-                DBUS_TYPE_STRING, display,
                 DBUS_TYPE_INVALID);
     if (!result)
     {
@@ -84,10 +80,10 @@ static DBusHandlerResult optsdbus_method_handler(DBusConnection *connection,
         EditColourScheme,
         OpenConfiglet
     } action = Unknown;
-    RTDBUS_ARG_CONST char *profile_name = NULL;
-    RTDBUS_ARG_CONST char *display_name = NULL;
-    char RTDBUS_ARG_CONST **parg = NULL;
-    GdkScreen *scrn = NULL;
+    const char *profile_name = NULL;
+    char const **parg = NULL;
+    (void) connection;
+    (void) user_data;
 
     dbus_error_init(&derror);
 
@@ -112,24 +108,21 @@ static DBusHandlerResult optsdbus_method_handler(DBusConnection *connection,
         case EditProfile:
         case EditColourScheme:
         case OpenConfiglet:
-            if (!optsdbus_read_args(message, parg, &display_name,
-                    &derror, &reply))
+            if (!optsdbus_read_args(message, parg, &derror, &reply))
             {
                 break;
             }
-            if (display_name && display_name[0])
-                scrn = display_get_screen_for_name(display_name);
             /* Fall-through */
             switch (action)
             {
                 case EditProfile:
-                    profilegui_open(profile_name, scrn);
+                    profilegui_open(profile_name);
                     break;
                 case EditColourScheme:
-                    colourgui_open(profile_name, scrn);
+                    colourgui_open(profile_name);
                     break;
                 case OpenConfiglet:
-                    configlet_open(scrn);
+                    configlet_open();
                     break;
                 default:
                     break;
@@ -139,8 +132,6 @@ static DBusHandlerResult optsdbus_method_handler(DBusConnection *connection,
 #if ROXTERM_DBUS_OLD_ARGS_SEMANTICS
             if (profile_name)
                 dbus_free(profile_name);
-            if (display_name)
-                dbus_free(display_name);
 #endif
             break;
         default:
@@ -152,8 +143,8 @@ static DBusHandlerResult optsdbus_method_handler(DBusConnection *connection,
 
     if (reply)
         rtdbus_send_message(reply);
-    
-    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;    
+
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
 static DBusMessage *optsdbus_signal_new(const char *signal_name,
@@ -161,8 +152,8 @@ static DBusMessage *optsdbus_signal_new(const char *signal_name,
 {
     return rtdbus_signal_new(OPTSDBUS_OBJECT_PATH, OPTSDBUS_INTERFACE,
             signal_name,
-            DBUS_TYPE_STRING, RTDBUS_ARG(profile_name),
-            DBUS_TYPE_STRING, RTDBUS_ARG(key),
+            DBUS_TYPE_STRING, &profile_name,
+            DBUS_TYPE_STRING, &key,
             DBUS_TYPE_INVALID);
 }
 
@@ -180,7 +171,7 @@ gboolean optsdbus_send_string_opt_signal(const char *profile_name,
         if (!value)
             value = "";
         if (!rtdbus_append_args(message,
-                DBUS_TYPE_STRING, RTDBUS_ARG(value), DBUS_TYPE_INVALID))
+                DBUS_TYPE_STRING, &value, DBUS_TYPE_INVALID))
         {
             return FALSE;
         }
@@ -206,7 +197,7 @@ gboolean optsdbus_send_int_opt_signal(const char *profile_name,
 
         dbus_error_init(&derror);
         if (!dbus_message_append_args(message,
-                DBUS_TYPE_INT32, RTDBUS_ARG(value), DBUS_TYPE_INVALID))
+                DBUS_TYPE_INT32, &value, DBUS_TYPE_INVALID))
         {
             return FALSE;
         }
@@ -232,7 +223,7 @@ gboolean optsdbus_send_float_opt_signal(const char *profile_name,
 
         dbus_error_init(&derror);
         if (!dbus_message_append_args(message,
-                DBUS_TYPE_DOUBLE, RTDBUS_ARG(value), DBUS_TYPE_INVALID))
+                DBUS_TYPE_DOUBLE, &value, DBUS_TYPE_INVALID))
         {
             return FALSE;
         }
@@ -260,7 +251,7 @@ gboolean optsdbus_send_stuff_changed_signal(const char *what_happened,
         if (new_name)
         {
             if (!dbus_message_append_args(message,
-                    DBUS_TYPE_STRING, RTDBUS_ARG(new_name), DBUS_TYPE_INVALID))
+                    DBUS_TYPE_STRING, &new_name, DBUS_TYPE_INVALID))
             {
                 return FALSE;
             }
@@ -270,17 +261,13 @@ gboolean optsdbus_send_stuff_changed_signal(const char *what_happened,
     return FALSE;
 }
 
-gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg,
-        const char *display_name)
+gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg)
 {
     DBusMessage * message;
-    
-    if (!display_name)
-        display_name = "";
+
     message = rtdbus_method_new(OPTSDBUS_NAME,
             OPTSDBUS_OBJECT_PATH, OPTSDBUS_INTERFACE, method,
-            DBUS_TYPE_STRING, RTDBUS_ARG(arg),
-            DBUS_TYPE_STRING, RTDBUS_ARG(display_name),
+            DBUS_TYPE_STRING, &arg,
             DBUS_TYPE_INVALID);
 
     if (!message)
@@ -290,7 +277,7 @@ gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg,
 
 gboolean optsdbus_init(void)
 {
-    return rtdbus_start_service(OPTSDBUS_NAME, OPTSDBUS_OBJECT_PATH, 
+    return rtdbus_start_service(OPTSDBUS_NAME, OPTSDBUS_OBJECT_PATH,
             optsdbus_method_handler, FALSE);
 }
 
@@ -305,9 +292,9 @@ static OptsDBusSetProfileHandler optsdbus_set_shortcut_scheme_handler = NULL;
 static gboolean optsdbus_set_profile_callback(OptsDBusSetProfileHandler handler,
         DBusMessage *message, DBusError *pderror)
 {
-    RTDBUS_ARG_CONST char *id_str = NULL;
-    RTDBUS_ARG_CONST char *profile_name = NULL;
-    
+    const char *id_str = NULL;
+    const char *profile_name = NULL;
+
     gboolean result = dbus_message_get_args(message, pderror,
             DBUS_TYPE_STRING, &id_str,
             DBUS_TYPE_STRING, &profile_name,
@@ -315,7 +302,7 @@ static gboolean optsdbus_set_profile_callback(OptsDBusSetProfileHandler handler,
     if (result)
     {
         void *id = NULL;
-        
+
         if (sscanf(id_str, "%p", &id) == 1)
         {
             handler(id, profile_name);
@@ -339,8 +326,8 @@ static DBusHandlerResult
 optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
     void *user_data)
 {
-    RTDBUS_ARG_CONST char *profile_name = NULL;
-    RTDBUS_ARG_CONST char *key = NULL;
+    const char *profile_name = NULL;
+    const char *key = NULL;
     OptsDBusValue val;
     char *dbus_str = NULL;
     const char *signal_name;
@@ -348,9 +335,12 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
     DBusError derror;
     OptsDBusOptType opt_type = OptsDBus_InvalidOpt;
     const char *what_happened = NULL;
-    RTDBUS_ARG_CONST char *family_name = NULL;
-    RTDBUS_ARG_CONST char *current_name = NULL;
-    RTDBUS_ARG_CONST char *new_name = NULL;
+    const char *family_name = NULL;
+    const char *current_name = NULL;
+    const char *new_name = NULL;
+
+    (void) connection;
+    (void) user_data;
 
     if (dbus_message_get_type(message) != DBUS_MESSAGE_TYPE_SIGNAL ||
         strcmp(dbus_message_get_path(message), OPTSDBUS_OBJECT_PATH))
@@ -396,7 +386,8 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
     }
     else if (!strcmp(signal_name, OPTSDBUS_DELETED)
              || !strcmp(signal_name, OPTSDBUS_ADDED)
-             || !strcmp(signal_name, OPTSDBUS_RENAMED))
+             || !strcmp(signal_name, OPTSDBUS_RENAMED)
+             || !strcmp(signal_name, OPTSDBUS_CHANGED))
     {
         what_happened = signal_name;
         if (strcmp(signal_name, OPTSDBUS_RENAMED))
@@ -533,8 +524,7 @@ void optsdbus_listen_for_set_shortcut_scheme_signals(
     optsdbus_set_shortcut_scheme_handler = handler;
 }
 
-gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg,
-        const char *display_name)
+gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg)
 {
     GError *error = NULL;
     char *appdir = global_options_appdir && global_options_appdir[0] ?
@@ -542,17 +532,13 @@ gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg,
     char *bindir = global_options_bindir ?
         g_strdup_printf("%s%c", global_options_bindir, G_DIR_SEPARATOR) :
         NULL;
-    char *disp = display_name ? g_strconcat("--display=", display_name, NULL) :
-            NULL;
     char *param = arg ? g_strdup_printf("--%s=%s", method, arg) :
             g_strdup(method);
-    char *command =  g_strdup_printf("%sroxterm-config %s %s '%s'",
-                bindir ? bindir : "", appdir ? appdir : "",
-                disp ? disp : "", param);
+    char *command =  g_strdup_printf("%sroxterm-config %s '%s'",
+                bindir ? bindir : "", appdir ? appdir : "", param);
 
     g_free(bindir);
     g_free(appdir);
-    g_free(disp);
     g_free(param);
     if (!g_spawn_command_line_async(command, &error))
     {
