@@ -1,8 +1,8 @@
 #ifndef OPTSDBUS_H
 #define OPTSDBUS_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #define OPTSDBUS_DELETED "OptionsDeleted"
 #define OPTSDBUS_ADDED "OptionsAdded"
 #define OPTSDBUS_RENAMED "OptionsRenamed"
+#define OPTSDBUS_CHANGED "OptionsChanged"
 
 #ifdef ROXTERM_CAPPLET
 
@@ -63,7 +64,7 @@ typedef enum {
 } OptsDBusOptType;
 
 typedef union {
-	RTDBUS_ARG_CONST char *s;
+	const char *s;
 	int i;
 	double f;
 } OptsDBusValue;
@@ -95,23 +96,18 @@ void optsdbus_listen_for_set_shortcut_scheme_signals(OptsDBusSetProfileHandler);
 /* In capplet this sends a D-BUS message to another instance; in terminal
  * it starts a new instance of the capplet which will either forward the
  * message to a previous instance or handle it itself. */
-gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg,
-        const char *display_name);
+gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg);
 
 inline static gboolean
-optsdbus_send_edit_profile_message(const char *profile_name,
-        const char *display_name)
+optsdbus_send_edit_profile_message(const char *profile_name)
 {
-	return optsdbus_send_edit_opts_message("EditProfile", profile_name,
-	        display_name);
+	return optsdbus_send_edit_opts_message("EditProfile", profile_name);
 }
 
 inline static gboolean
-optsdbus_send_edit_colour_scheme_message(const char *profile_name,
-        const char *display_name)
+optsdbus_send_edit_colour_scheme_message(const char *profile_name)
 {
-	return optsdbus_send_edit_opts_message("EditColourScheme", profile_name,
-	        display_name);
+	return optsdbus_send_edit_opts_message("EditColourScheme", profile_name);
 }
 
 #endif /* OPTSDBUS_H */
