@@ -1,8 +1,8 @@
 #ifndef ROXTERM_H
 #define ROXTERM_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 
 #include <vte/vte.h>
 
+#include "multitab.h"
+
 typedef struct ROXTermData ROXTermData;
 
 /* Make sure global options have been parsed before calling this, but call it
@@ -34,11 +36,10 @@ typedef struct ROXTermData ROXTermData;
  */
 void roxterm_init(void);
 
-/* Launch a new terminal in response to a D-BUS message or for first
- * time; display_name may be NULL for default display.
+/* Launch a new terminal in response to a D-BUS message or for first time.
  * env is copied without being altered.
  */
-void roxterm_launch(const char *display_name, char **env);
+void roxterm_launch(char **env);
 
 /* Ways of spawning a command */
 typedef enum {
@@ -52,14 +53,14 @@ typedef enum {
 void roxterm_spawn(ROXTermData *, const char *command, ROXTerm_SpawnType);
 
 gboolean roxterm_spawn_command_line(const gchar *command_line,
-        const char *display_name, const char *cwd, char **env, GError **error);
+        const char *cwd, char **env, GError **error);
 
 VteTerminal *roxterm_get_vte_terminal(ROXTermData *roxterm);
 
 const char *roxterm_get_profile_name(ROXTermData *roxterm);
 
 const char *roxterm_get_colour_scheme_name(ROXTermData *roxterm);
-        
+
 char *roxterm_get_cwd(ROXTermData *roxterm);
 
 /* Returns non-full-screen dimensions */
@@ -69,10 +70,31 @@ double roxterm_get_zoom_factor(ROXTermData *roxterm);
 
 char const * const *roxterm_get_actual_commandv(ROXTermData *roxterm);
 
-#if ENABLE_SM
+void roxterm_stuff_changed_handler(const char *what_happened,
+        const char *family_name, const char *current_name,
+        const char *new_name);
+
 gboolean roxterm_load_session(const char *xml, gssize len,
         const char *client_id);
-#endif
+
+MultiWin *roxterm_get_multi_win(ROXTermData *roxterm);
+
+VteTerminal *roxterm_get_vte(ROXTermData *roxterm);
+
+typedef enum {
+    ROXTERM_SEARCH_MATCH_CASE = 1,
+    ROXTERM_SEARCH_ENTIRE_WORD = 2,
+    ROXTERM_SEARCH_AS_REGEX = 4,
+    ROXTERM_SEARCH_BACKWARDS = 8,
+    ROXTERM_SEARCH_WRAP = 16
+} ROXTermSearchFlags;
+
+/* Returns FALSE and sets error if unable to compile regex */
+gboolean roxterm_set_search(ROXTermData *roxterm,
+        const char *pattern, guint flags, GError **error);
+
+const char *roxterm_get_search_pattern(ROXTermData *roxterm);
+guint roxterm_get_search_flags(ROXTermData *roxterm);
 
 #endif /* ROXTERM_H */
 
