@@ -1,8 +1,8 @@
 #ifndef URI_H
 #define URI_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,12 +26,7 @@
 #include "defns.h"
 #endif
 
-/* Returns a command for launching a URL in the given browser, which may
- * contain '%s for URL substitution, otherwise the URL is appended. If browser
- * is null, it tries to find one. Result should be freed after use. */
-char *uri_get_browser_command(const char *url, const char *browser);
-
-char *uri_get_mailer_command(const char *address, const char *mailer);
+char *uri_get_ssh_command(const char *uri, const char *ssh);
 
 #endif /* URI_H */
 
